@@ -95,6 +95,9 @@ getClosestMunsellChip <- function(munsellColor, convertColors=TRUE, ...) {
 
 
 ## TODO: this will not correctly parse gley
+## TODO: re-write with REGEX for extraction from within other text
+## TODO: short-circuit for obviously wrong Munsell codes
+#
 # convert a color string '10YR 4/3' to sRGB or R color
 parseMunsell <- function(munsellColor, convertColors=TRUE, ...) {
   # sanity check:
@@ -118,7 +121,7 @@ parseMunsell <- function(munsellColor, convertColors=TRUE, ...) {
   return(res)
 }
 
-
+## TODO: distance calculation should be delta-E00, sigma is delta-E00 to closest chip
 # color is a matrix/data.frame of sRGB values in range of [0,1]
 # ideally output from munsell2rgb()
 rgb2munsell <- function(color, colorSpace='LAB', nClosest=1) {
@@ -191,7 +194,7 @@ rgb2munsell <- function(color, colorSpace='LAB', nClosest=1) {
 # TODO if alpha is greater than maxColorValue, there will be an error
 # convert munsell Hue, Value, Chroma into sRGB
 # user can adjust how rgb() function will return an R-friendly color
-munsell2rgb <- function(the_hue, the_value, the_chroma, alpha=1, maxColorValue=1, return_triplets=FALSE) {
+munsell2rgb <- function(the_hue, the_value, the_chroma, alpha=1, maxColorValue=1, return_triplets=FALSE, returnLAB=FALSE) {
 	## important: change the default behavior of data.frame and melt
   opt.original <- options(stringsAsFactors = FALSE)
   
@@ -204,7 +207,7 @@ munsell2rgb <- function(the_hue, the_value, the_chroma, alpha=1, maxColorValue=1
 		stop('All inputs must be vectors of equal length.')
 	
   ## plyr <= 1.6 : check to make sure hue is a character
-  if(class(the_hue) == 'factor') {
+  if(is.factor(the_hue)) {
     cat('Notice: converting hue to character\n')
     the_hue <- as.character(the_hue)
   }
@@ -237,9 +240,16 @@ munsell2rgb <- function(the_hue, the_value, the_chroma, alpha=1, maxColorValue=1
   # reset options:
   options(opt.original)
   
-	# if the user wants the raw RGB triplets, give those back
+  # syntax is now a little muddled, test for sRGB and LAB
+  if(return_triplets & returnLAB)
+    return(res[, c('r','g','b', 'L', 'A', 'B')])
+  
+	# if the user wants the raw sRGB triplets, give those back
 	if(return_triplets)
 		return(res[, c('r','g','b')])
+  
+  if(returnLAB)
+    return(res[, c('L','A','B')])
 	
 	# keep track of NA values
 	rgb.na <- which(is.na(res$r))
