@@ -55,7 +55,11 @@ plot.depth.matrix=FALSE, rescale.result=FALSE, verbose=FALSE) {
 	# compute a weighting vector based on k	
 	w <- 1 * exp(-k * depth_slice_seq)
 		
-	## TODO: convert to slice()
+	## TODO: convert to slice() (#7)
+	## BUG: !!! this step re-orders via string-factor-string conversion step by split() (#7)
+	## --> this is only a bug when profile IDs have been altered after SPC init
+	## --> https://stackoverflow.com/questions/17611734/r-split-preserving-natural-order-of-factors
+	##
 	## unroll each named soil property, for each soil profile
 	## the result is a list matricies with dimensions: depth, num_properties 
 	# this approach requires a named list of soil properties
@@ -88,7 +92,7 @@ plot.depth.matrix=FALSE, rescale.result=FALSE, verbose=FALSE) {
 		# evaluated based on presence of real data in at least 1 variable
 		s.sub <- na.omit(s[, c('id', 'top', 'bottom', vars)])
     
-    ## BUG!!! tapply() re-orders the results based on sorting of s.sub$id
+    ## BUG!!! tapply() re-orders the results based on sorting of s.sub$id (#7)
     ## ----> this will cause problems when input isn't sorted by ID
 		# get the depth of each profile
 		s.slices_of_soil <- tapply(s.sub$bottom, s.sub$id, max, na.rm=TRUE)
@@ -115,6 +119,7 @@ plot.depth.matrix=FALSE, rescale.result=FALSE, verbose=FALSE) {
 			else
 				image.cols <- c('grey')
 			
+			## TODO: use SPC methods, unique() will not return labels in the correct order
       # labs <- profile_id(s)
 		  labs <- unique(s.sub$id)
 		  image(x=1:n.profiles, y=1:max_d, z=t(soil.matrix), col=image.cols, ylim=c(max_d, 0), xlab='ID', ylab='Slice Number (usually eq. to depth)', main='Soil / Non-Soil Matrix', axes=FALSE)
@@ -134,7 +139,7 @@ plot.depth.matrix=FALSE, rescale.result=FALSE, verbose=FALSE) {
 	## 
 	message(paste('Computing dissimilarity matrices from', n.profiles, 'profiles'), appendLF=FALSE)
 	
-	## TEMP HACK to supress warnings generated by calling daisy with all NA input
+	## TEMP HACK to supress warnings generated by calling daisy with all NA input (#7)
 	ow <- options('warn')
 	options(warn=-1)
 	
@@ -152,7 +157,7 @@ plot.depth.matrix=FALSE, rescale.result=FALSE, verbose=FALSE) {
 		## an ff object would help here... however it can not preserve all of the information 
 		## that a list can... we would need to store these data as raw matrices
 	  
-	  ## TODO: don't call daisy on bogus input data, temp fix: disable warnings
+	  ## TODO: don't call daisy on bogus input data, temp fix: disable warnings (#7)
 	  ## if all of the input to daisy is NA, then we get warnings from min() and max()
 	  ## this happens when we set a max depth that is beyond most profiles
 	  d.i <- daisy(sp, metric='gower')
@@ -282,7 +287,7 @@ pc.SPC <- function(s, vars, rescale.result=FALSE, ...){
   # iterate over profiles and compute percent missing data by variable
   pct_data <- evalMissingData(s, vars)
   
-  ## TODO: review this, and make optional via argument
+  ## TODO: review this, and make optional via argument (#7)
   # keep track of profiles missing any or all of their data
   problem.profiles.idx <- which(pct_data < 1)
   # bad.profiles.idx <- which(pct_data == 0)
@@ -368,6 +373,13 @@ pc.SPC <- function(s, vars, rescale.result=FALSE, ...){
 		res <- rescale(res)
 	}
 	
+	## fail-safe check on ordering of input profile IDs vs. labels
+	## #7
+	test.labels <- ! profile_id(s) == attributes(res)$Labels
+	if(any(test.labels)) {
+	  stop('input/output IDs out of order\nthis happens when profile IDs have been changed after SPC init\nsorry, soon to be fixed (#7)', call. = FALSE)
+	}
+	
 	# result is a distance matrix
 	return(res)
 }
