@@ -16,9 +16,15 @@ rebuildSPC <- function(x) {
   # add additional pieces
   metadata(res) <- x.list$metadata
   site(res) <- x.list$site
-  res@sp <- x.list$sp
   diagnostic_hz(res) <- x.list$diagnostic
   
+  # copy valid spatial data from the source object
+  # otherwise, the previous and possibly invalid SpatialPoints object created by horizons() is fine
+  if(validSpatialData(x)) {
+    res@sp <- x.list$sp
+  }
+  
+  # done
   return(res)
 }
 
